MatMult

Struct MatMult 

pub struct MatMult<F: Field> {
    layer_id: LayerId,
    matrix_a: Matrix<F>,
    matrix_b: Matrix<F>,
    num_vars_middle_ab: usize,
}
Used to represent a matrix multiplication layer.

#Attributes:

  • layer_id - the LayerId of this MatMult layer.
  • matrix_a - the lefthand side matrix in the multiplication.
  • matrix_b - the righthand side matrix in the multiplication.

Fields

layer_id: LayerIdmatrix_a: Matrix<F>matrix_b: Matrix<F>num_vars_middle_ab: usize

Implementations

Source

impl<F: Field> MatMult<F>

pub fn new( layer_id: LayerId, matrix_a: Matrix<F>, matrix_b: Matrix<F>, ) -> MatMult<F>

Create a new matrix multiplication layer.

fn pre_processing_step(&mut self, claim_a: Vec<F>, claim_b: Vec<F>)

The step, according to Tha13, which makes the matmult algorithm super-efficient.

Given the claim on the output of the matrix multiplication, we bind the variables representing the “rows” of matrix_a to the first log(num_rows_a) vars in this claim, and we bind the variables representing the “columns” of matrix_b to the last log(num_cols_b) vars in the claim.

#Arguments

  • claim_a: the first log_num_rows variables of the claim made on the MLE representing the output of this layer.
  • claim_b: the last log_num_cols variables of the claim made on the MLE representing the output of this layer.
fn append_leaf_mles_to_transcript( &self, transcript_writer: &mut impl ProverTranscript<F>, )